/**
 * Copyright 2001-2013 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.easymock.internal;

/**
 * @author OFFIS, Tammo Freese
 */
public class AssertionErrorWrapper extends RuntimeException {

    private static final long serialVersionUID = -2087349195182278608L;

    private final AssertionError error;

    public AssertionErrorWrapper(final AssertionError error) {
        this.error = error;
    }

    public AssertionError getAssertionError() {
        return error;
    }
}
